# Gemini models
GEMINI_PRO = "google/gemini-2.5-pro"
GEMINI_FLASH = "google/gemini-2.5-flash"

# OLLAMA models
OLLAMA_EMBEDDING_MODEL = "nomic-embed-text:latest"
OLLAMA_GENERATIVE_MODEL = "gemma3:4b"

# Default embedding dimensions
DEFAULT_EMBEDDING_DIMS = 768
